import { Box, CssBaseline, ThemeProvider, createTheme } from '@mui/material';
import blue from '@mui/material/colors/blue';
import pink from '@mui/material/colors/pink';
import { SnackbarProvider } from 'notistack';
import React, { FC, useMemo, useState } from 'react';
import { Route, MemoryRouter as Router, Routes } from 'react-router-dom';
import { RecoilRoot } from 'recoil';

import { CompareStudies } from './CompareStudies';
import { StudyDetail } from './StudyDetail';
import { StudyList } from './StudyList';

export const App: FC = () => {
  const [colorMode, setColorMode] = useState<'light' | 'dark'>('light');
  const theme = useMemo(
    () =>
      createTheme({
        palette: {
          mode: colorMode,
          primary: blue,
          secondary: pink
        }
      }),
    [colorMode]
  );
  const toggleColorMode = () => {
    setColorMode(colorMode === 'dark' ? 'light' : 'dark');
  };

  return (
    <RecoilRoot>
      <ThemeProvider theme={theme}>
        <CssBaseline />
        <Box
          sx={{
            backgroundColor: colorMode === 'dark' ? '#121212' : '#ffffff',
            width: '100%',
            minHeight: '100vh'
          }}
        >
          <SnackbarProvider maxSnack={3}>
            <Router>
              <Routes>
                <Route
                  path={'/studies/:studyId/analytics'}
                  element={
                    <StudyDetail
                      toggleColorMode={toggleColorMode}
                      page={'analytics'}
                    />
                  }
                />
                <Route
                  path={'/studies/:studyId/trials'}
                  element={
                    <StudyDetail
                      toggleColorMode={toggleColorMode}
                      page={'trialList'}
                    />
                  }
                />
                <Route
                  path={'/studies/:studyId/trials'}
                  element={
                    <StudyDetail
                      toggleColorMode={toggleColorMode}
                      page={'trialList'}
                    />
                  }
                />
                <Route
                  path={'/studies/:studyId/trialTable'}
                  element={
                    <StudyDetail
                      toggleColorMode={toggleColorMode}
                      page={'trialTable'}
                    />
                  }
                />
                <Route
                  path={'/studies/:studyId/note'}
                  element={
                    <StudyDetail
                      toggleColorMode={toggleColorMode}
                      page={'note'}
                    />
                  }
                />
                <Route
                  path={'/studies/:studyId'}
                  element={
                    <StudyDetail
                      toggleColorMode={toggleColorMode}
                      page={'history'}
                    />
                  }
                />
                <Route
                  path={'/compare-studies'}
                  element={<CompareStudies toggleColorMode={toggleColorMode} />}
                />
                <Route
                  path={'/'}
                  element={<StudyList toggleColorMode={toggleColorMode} />}
                />
              </Routes>
            </Router>
          </SnackbarProvider>
        </Box>
      </ThemeProvider>
    </RecoilRoot>
  );
};
